package de.intevation.flys.artifacts.model.sq;

import de.intevation.artifactdatabase.state.Facet;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.CallContext;

import de.intevation.flys.artifacts.FLYSArtifact;

import de.intevation.flys.artifacts.model.CalculationResult;
import de.intevation.flys.artifacts.model.DataFacet;
import de.intevation.flys.artifacts.model.FacetTypes;

import de.intevation.flys.artifacts.states.DefaultState.ComputeType;

import org.apache.log4j.Logger;

public class SQOutlierMeasurementFacet
extends      DataFacet
implements   FacetTypes
{
    private static final Logger log =
        Logger.getLogger(SQOutlierMeasurementFacet.class);

    private int fractionIdx;

    public static final int BITMASK_ITERATION = (1 << 16) - 1;

    public SQOutlierMeasurementFacet() {
    }

    public SQOutlierMeasurementFacet(
        int    idx,
        int    fractionIdx,
        String name,
        String description,
        String hash,
        String stateId
    ) {
        super(idx, name, description, ComputeType.ADVANCE, hash, stateId);
        this.fractionIdx = fractionIdx;
    }

    @Override
    public Object getData(Artifact artifact, CallContext context) {
        log.debug("SQOutlierMeasurementFacet.getData");

        if (!(artifact instanceof FLYSArtifact)) {
            return null;
        }

        FLYSArtifact flys = (FLYSArtifact) artifact;

        CalculationResult res = (CalculationResult) flys.compute(
            context, ComputeType.ADVANCE, false);

        int idx  = this.index >> 16;
        int iter = this.index & BITMASK_ITERATION;

        SQResult[]       result  = (SQResult[]) res.getData();
        SQFractionResult fResult = result[idx].getFraction(fractionIdx);

        return fResult.getMeasurements(iter);
    }

    @Override
    public Facet deepCopy() {
        SQOutlierMeasurementFacet copy = new SQOutlierMeasurementFacet();
        copy.set(this);
        return copy;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
